# This is a one of two related Makefiles for easy-DLL'ing.
# Change DYNMAKE below to the appropriate location of the second makefile.
# The reason for two makefiles is that the .def file should never
# be automatically updated, but should be automatically created.
#
# Use like 
#
# make; make install; make clean
#
# or
#
# make definition; manually edit .DEF file; make; make install; make clean
# 
# Make realclean will erase .DEF file. Do not do this if you want to preserve
# binary compatibility between version.
#
# If you have perl you may generate a good .DEF file like this:
#
# make smartdefinition

# Change this location in the sample file and copy-on-write the sample ;-):

DYNMAKE = f:/emx.add/lib/Makefile.dynamic

### This should be customized for your particular library:

# These two are required

LIB = tcl

# FILES = list-of-files-with-the-same-basenames-as-OBJECTS, optional
UNIX_OBJS = tclMtherr.o tclUnixChan.o tclUnixFile.o \
	tclUnixNotfy.o tclUnixPipe.o tclUnixSock.o tclUnixTime.o \
	tclUnixInit.o
DL_OBJS = dl_os2.o tclLoadDl.o
# COMPAT_OBJS =		 strncasecmp.o
TCLSH_OBJS = tclAppInit.o
TCLTEST_OBJS = tclTestInit.o tclTest.o tclUnixTest.o

GENERIC_OBJS = panic.o regexp.o tclAsync.o tclBasic.o tclCkalloc.o \
	tclClock.o tclCmdAH.o tclCmdIL.o tclCmdMZ.o tclDate.o tclEnv.o \
	tclEvent.o tclExpr.o tclFHandle.o tclFileName.o tclGet.o tclHash.o \
	tclHistory.o tclInterp.o tclIO.o tclIOCmd.o \
	tclIOSock.o tclIOUtil.o tclLink.o tclLoad.o tclMain.o tclNotify.o \
	tclParse.o tclPkg.o tclPosixStr.o tclPreserve.o tclProc.o \
	tclUtil.o tclVar.o
FILES = ${GENERIC_OBJS} ${UNIX_OBJS} ${COMPAT_OBJS} ${DL_OBJS}

# OBJECTS = termcap.obj tgoto.obj tputs.obj
# OBJECTS = $(LIB).obj

# If you may paste the list of files with "wrong" extensions, define
# FILES to be this list, and uncomment the following definition for gnumake:

OBJECTS = $(addsuffix .obj,$(basename $(FILES)))
TCLSH_OBJECTS = $(addsuffix .obj,$(basename $(TCLSH_OBJS)))
TCLTEST_OBJECTS = $(addsuffix .obj,$(basename $(TCLTEST_OBJS)))


# These are optional:

VERSION = 7.5
prefix = f:
TCL_LIBRARY =	$(prefix)/lib/tcl$(VERSION)
SHLIB_SUFFIX = .dll
tcl_dir = ../../tcl$(VERSION)

DEFS = -Zmtd -DEMX -DNO_WAIT3=1 -DHAVE_UNISTD_H=1 -DHAVE_SYS_TIME_H=1 -DTIME_WITH_SYS_TIME=1 -DHAVE_TZNAME=1 -DHAVE_TIMEZONE_VAR=1 -DSTDC_HEADERS=1 -DNO_UNION_WAIT=1 -Dvfork=fork  -DTCL_LIBRARY=\\\"${TCL_LIBRARY}\\\" -DTCL_SHLIB_EXT=\\\"${SHLIB_SUFFIX}\\\"
CFLAGS = -g
LIBS = -Zmtd -lsocket
INCLUDES = -I$(tcl_dir)/generic -I$(tcl_dir)/unix -I.


# This is used for smartdefinition: List of header files which contain
# the external names for the library.

MYINCLUDES = $(LIB).h tclInt.h

# Script to use to filter out unneeded symbols 
# (entry points in DLL are case-insensitive). Comment if not needed:

# Default (remove the case-dublicate symbols completely):
# SETFILTER = "FILTER=filtersym.cmd"

# No filtering:
# SETFILTER = "FILTER=@cmd /c rem"

# Alternative directories for .c files

ALTERN1 = $(tcl_dir)/unix
ALTERN2 = $(tcl_dir)/generic
ALTERN3 = .

### This is the end of customization section

RM = cmd /c del
MAKE2 =	$(MAKE) -f $(DYNMAKE) \
		LIB=$(LIB) "OBJECTS=$(OBJECTS)" "INCLUDES=$(INCLUDES)" \
		"DEFS=$(DEFS)" "LIBS=$(LIBS)" "CFLAGS=$(CFLAGS)" \
		"ADDSYMBOLS=$(ADDSYMBOLS)" $(SETFILTER) \
		"ALTERN1=$(ALTERN1)" "ALTERN2=$(ALTERN2)" "ALTERN3=$(ALTERN3)" \
		"MYINCLUDES=$(MYINCLUDES)"

.SUFFIXES:	.c .obj .lib

.c.obj:
	$(MAKE2) $*.obj

%.obj: $(ALTERN1)/%.c
	$(MAKE2) $*.obj

%.obj: $(ALTERN2)/%.c
	$(MAKE2) $*.obj

%.obj: $(ALTERN3)/%.c
	$(MAKE2) $*.obj

all: dynamic tclsh.exe tcltest.exe

dynamic: $(LIB).dll $(LIB)_import.a $(LIB)_import.lib

tclsh.exe : $(TCLSH_OBJECTS) $(LIB)_import.lib
	gcc -Zmtd -Zomf -Zcrtdll -o $@ $(TCLSH_OBJECTS) $(LIB)_import.lib

tcltest.exe : $(TCLTEST_OBJECTS) $(LIB)_import.lib
	gcc -Zmtd -Zomf -Zcrtdll -o $@ $(TCLTEST_OBJECTS) $(LIB)_import.lib

# Extra quoting, thus extra shell:

tclTestInit.obj: $(tcl_dir)/unix/tclAppInit.c
	cmd /c gcc -Zomf -DTCL_TEST $(INCLUDES) $(DEFS) -o $@ -c $< 

definition: $(LIB).def

$(LIB).dll $(LIB)_import.a $(LIB)_import.lib : $(LIB).def $(OBJECTS)
	$(MAKE2)

$(LIB).def:
	$(MAKE2) definition

smartdefinition: $(LIB).def
	$(MAKE2) smartdefinition

install: $(LIB).def $(LIB).dll $(LIB)_import.a $(LIB)_import.lib
	$(MAKE2) install 

clean:
	-$(RM) $(OBJECTS) $(LIB).dll $(LIB).lib $(LIB)_import.a $(LIB)_import.lib tmptmp.tmp $(LIB).tmp 2> nul

realclean: clean
	-$(RM) $(LIB).def 2> nul
